"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const xml2js_1 = require("xml2js");
const invalid_credentials_error_1 = require("../errors/invalid-credentials-error");
const parse_error_1 = require("../errors/parse-error");
const axios_1 = __importDefault(require("axios"));
class ModelRequest {
    constructor(config, area) {
        const baseUrl = 'https://www.aisweb.aer.mil.br/api/';
        this.requestUrl = `${baseUrl}?apiKey=${config.apiKey}&apiPass=${config.apiPass}&area=${area}`;
    }
    performRequest(airportIcao) {
        return this.apiFetcher(airportIcao)
            .then(this.xmlParse)
            .then(this.processRequest);
    }
    apiFetcher(airportIcao) {
        return axios_1.default.get(`${this.requestUrl}&IcaoCode=${airportIcao}`)
            .then(response => {
            if (response.data.includes('Informe uma chave válida na URL') ||
                response.data.includes('Erro nos parametros obrigatórios')) {
                throw new invalid_credentials_error_1.InvalidCredentialsError('Informed credentials are invalid');
            }
            return response.data;
        });
    }
    xmlParse(data) {
        let parsedData = null;
        if (data.indexOf('total="0"') !== -1) {
            return null;
        }
        xml2js_1.parseString(data, (error, result) => {
            if (error) {
                throw new parse_error_1.ParseError('There was a problem parsing the XML data');
            }
            parsedData = result;
        });
        return parsedData.aisweb;
    }
}
exports.ModelRequest = ModelRequest;
