"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const api_areas_1 = require("../common/api-areas");
const model_request_1 = require("../common/model-request");
const factories_1 = require("../factories");
class RotaerRequest extends model_request_1.ModelRequest {
    constructor(config) {
        super(config, api_areas_1.ApiAreas.rotaer);
    }
    processRequest(result) {
        if (typeof result === 'string') {
            return [];
        }
        const rotaer = new factories_1.Rotaer({
            AeroCode: result.AeroCode[0],
            altitude: parseInt(result.altFt[0], 10),
            category: result.cat[0],
            ciad: result.ciad[0],
            city: result.city[0],
            complements: processComplements(result.compls),
            distance: result.distance[0],
            fir: result.fir[0],
            jurisdiction: result.jur[0],
            lat: parseFloat(result.lat[0]),
            latRotaer: result.latRotaer[0],
            lights: processLights(result.lights),
            lng: parseFloat(result.lng[0]),
            lngRotaer: result.lngRotaer[0],
            name: result.name[0],
            organization: {
                military: result.org[0].military[0],
                name: result.org[0].name[0],
                type: result.org[0].type[0],
            },
            remarks: processRemarks(result.rmk[0]),
            runways: processRunways(result.runways),
            state: result.uf[0],
            status: result.status[0],
            type: result.type[0],
            typeUtil: result.typeUtil[0],
            UTC: parseInt(result.utc[0], 10),
            workinghour: result.workinghour[0],
        });
        return [rotaer];
    }
}
exports.RotaerRequest = RotaerRequest;
function processComplements(complements) {
    if (complements[0].compl) {
        return complements[0].compl.map((value) => ({
            code: value.$.cod,
            complement: value._,
        }));
    }
    return [];
}
function processLights(lights) {
    if (lights[0].light) {
        return lights[0].light.map((value) => ({
            code: value._,
            description: value.$.descr,
        }));
    }
    return [];
}
function processRemarks(remakrs) {
    if (remakrs.rmkText) {
        return remakrs.rmkText.map((value) => ({
            code: value.$.cod,
            remark: value._,
        }));
    }
    return [];
}
function processRunways(runways) {
    if (runways[0].runway) {
        return runways[0].runway.map((value) => ({
            ident: value.ident[0],
            length: parseInt(value.length[0]._, 10),
            lights: processLights(value.lights),
            surface: value.surface_c[0]._,
            thresholds: processThresholds(runways[0].runway[0].thr),
            type: value.type[0],
            width: parseInt(value.width[0]._, 10),
        }));
    }
    return [];
}
function processThresholds(thresholds) {
    if (thresholds) {
        return thresholds.map((value) => ({
            ident: value.ident[0],
            lights: processLights(value.lights),
        }));
    }
    return [];
}
